#
# LurkenPlone setup tests
#

import os, sys
if __name__ == '__main__':
    execfile(os.path.join(sys.path[0], 'framework.py'))

from Products.PloneTestCase import PloneTestCase

PloneTestCase.installProduct('LurkenPlone')
PloneTestCase.setupPloneSite(products=('LurkenPlone',))

from Products.LurkenPlone.Extensions.Install import uninstall
from Products.LurkenPlone.Extensions.Install import styleSheetProperties


class TestInstall(PloneTestCase.PloneTestCase):

    def afterSetUp(self):
        self.skins = self.portal.portal_skins
        self.css = self.portal.portal_css

    def testSkinFolder(self):
        ids = self.skins.objectIds()
        self.failUnless('LurkenPlone' in ids)

    def testSkinFolderContents(self):
        ids = self.skins.LurkenPlone.objectIds()
        self.failUnless('base_properties' in ids)
        self.failUnless('lurkenplone.css' in ids)
        self.failUnless('lurkenplone-member.css' in ids)
        self.failUnless('lurkenplone-logo.gif' in ids)

    def testSkinSelections(self):
        selections = self.skins.getSkinSelections()
        self.failUnless('LurkenPlone' in selections)

    def testSkinLayer(self):
        path = self.skins.getSkinPath('LurkenPlone')
        self.assertEqual(path[:19], 'custom,LurkenPlone,')

    def testBaseStylesheet(self):
        ids = list(self.css.getResourceIds())
        self.failUnless('lurkenplone.css' in ids)
        # Should be right before ploneCustom.css
        self.assertEqual(ids.index('lurkenplone.css'), len(ids)-2)

    def testBaseStylesheetProperties(self):
        r = self.css.getResource('lurkenplone.css')
        p = styleSheetProperties['lurkenplone.css']
        self.assertEqual(r.getEnabled(), p['enabled'])
        self.assertEqual(r.getTitle(), p['title'])
        self.assertEqual(r.getExpression(), p['expression'])
        self.assertEqual(r.getCookable(), p['cookable'])
        self.assertEqual(r.getMedia(), p['media'])
        self.assertEqual(r.getRel(), p['rel'])
        self.assertEqual(r.getRendering(), p['rendering'])

    def testMemberStylesheet(self):
        ids = list(self.css.getResourceIds())
        self.failUnless('lurkenplone-member.css' in ids)
        # Should be right before lurkenplone.css
        self.assertEqual(ids.index('lurkenplone-member.css'), len(ids)-3)

    def testMemberStylesheetProperties(self):
        r = self.css.getResource('lurkenplone-member.css')
        p = styleSheetProperties['lurkenplone-member.css']
        self.assertEqual(r.getEnabled(), p['enabled'])
        self.assertEqual(r.getTitle(), p['title'])
        self.assertEqual(r.getExpression(), p['expression'])
        self.assertEqual(r.getCookable(), p['cookable'])
        self.assertEqual(r.getMedia(), p['media'])
        self.assertEqual(r.getRel(), p['rel'])
        self.assertEqual(r.getRendering(), p['rendering'])

    def testDefaultSkin(self):
        self.assertEqual(self.skins.getDefaultSkin(), 'LurkenPlone')


class TestUninstall(PloneTestCase.PloneTestCase):

    def afterSetUp(self):
        self.skins = self.portal.portal_skins
        self.css = self.portal.portal_css
        self.qi = self.portal.portal_quickinstaller
        self.qi.uninstallProducts(['LurkenPlone'])

    def testSkinFolder(self):
        ids = self.skins.objectIds()
        self.failIf('LurkenPlone' in ids)

    def testSkinSelections(self):
        selections = self.skins.getSkinSelections()
        self.failIf('LurkenPlone' in selections)

    def testBaseStylesheet(self):
        ids = self.css.getResourceIds()
        self.failIf('lurkenplone.css' in ids)

    def testMemberStylesheet(self):
        ids = self.css.getResourceIds()
        self.failIf('lurkenplone-member.css' in ids)

    def testDefaultSkin(self):
        self.assertEqual(self.skins.getDefaultSkin(), 'Plone Default')


class TestManualUninstall(TestUninstall):

    def afterSetUp(self):
        self.skins = self.portal.portal_skins
        self.css = self.portal.portal_css
        self.loginAsPortalOwner()
        uninstall(self.portal)


def test_suite():
    from unittest import TestSuite, makeSuite
    suite = TestSuite()
    suite.addTest(makeSuite(TestInstall))
    suite.addTest(makeSuite(TestUninstall))
    suite.addTest(makeSuite(TestManualUninstall))
    return suite

if __name__ == '__main__':
    framework()

